@@ -1,5 +1,5 @@
 /* This file is part of GNU Dico
-   Copyright (C) 2003-2004, 2007-2008, 2010, 2012 Sergey Poznyakoff
+   Copyright (C) 2003-2018 Sergey Poznyakoff
   
    GNU Dico is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -52,7 +52,7 @@ cmp_ptr(const void *a, void *b)
 }
 
 struct dico_list *
-dico_list_create()
+dico_list_create(void)
 {
     struct dico_list *p = malloc(sizeof(*p));
     if (p) {
